@@ -10,18 +10,18 @@ import exceptions
 
 logging.getLogger('suds.client').setLevel(logging.INFO)
 
-PATH = settings.OPENKM['Path']
+PATH = settings.OPENKM['configuration']['Path']
 
 OPENKM_WSDLS = {
-    'Auth': settings.OPENKM['Host'] + '%s/OKMAuth?wsdl' % PATH,
-    'Bookmark': settings.OPENKM['Host'] + '%s/OKMBookmark?wsdl' % PATH,
-    'Document': settings.OPENKM['Host'] + '%s/OKMDocument?wsdl' % PATH,
-    'Search': settings.OPENKM['Host'] + '%s/OKMSearch?wsdl' % PATH,
-    'Note': settings.OPENKM['Host'] + '%s/OKMNote?wsdl' % PATH,
-    'Folder': settings.OPENKM['Host'] + '%s/OKMFolder?wsdl' % PATH,
-    'Property': settings.OPENKM['Host'] + '%s/OKMProperty?wsdl' % PATH,
-    'PropertyGroup': settings.OPENKM['Host'] + '%s/OKMPropertyGroup?wsdl' % PATH,
-    'Repository': settings.OPENKM['Host'] + '%s/OKMRepository?wsdl' % PATH,
+    'Auth': settings.OPENKM['configuration']['Host'] + '%s/OKMAuth?wsdl' % PATH,
+    'Bookmark': settings.OPENKM['configuration']['Host'] + '%s/OKMBookmark?wsdl' % PATH,
+    'Document': settings.OPENKM['configuration']['Host'] + '%s/OKMDocument?wsdl' % PATH,
+    'Search': settings.OPENKM['configuration']['Host'] + '%s/OKMSearch?wsdl' % PATH,
+    'Note': settings.OPENKM['configuration']['Host'] + '%s/OKMNote?wsdl' % PATH,
+    'Folder': settings.OPENKM['configuration']['Host'] + '%s/OKMFolder?wsdl' % PATH,
+    'Property': settings.OPENKM['configuration']['Host'] + '%s/OKMProperty?wsdl' % PATH,
+    'PropertyGroup': settings.OPENKM['configuration']['Host'] + '%s/OKMPropertyGroup?wsdl' % PATH,
+    'Repository': settings.OPENKM['configuration']['Host'] + '%s/OKMRepository?wsdl' % PATH,
     }
 
 def try_except(fn):
@@ -51,11 +51,14 @@ def get_token():
     auth.login()
     return auth.token
 
+
 class BaseService(object):
 
-    def __init__(self, start_session=True):
-        self.service = get_service(self.__class__.__name__)
-        self.client = get_client(self.__class__.__name__)
+    def __init__(self, start_session=True, class_name=None):
+        if not class_name:
+            class_name = self.__class__.__name__
+        self.service = get_service(class_name)
+        self.client = get_client(class_name)
         if start_session:
             self.token = get_token()
 
@@ -66,7 +69,7 @@ class Auth(BaseService):
     def __init__(self):
         super(Auth, self).__init__(start_session=False)
 
-    def login(self, user=settings.OPENKM['User'], password=settings.OPENKM['Password']):
+    def login(self, user=settings.OPENKM['configuration']['User'], password=settings.OPENKM['configuration']['Password']):
         self.token = self.service.login(user=user, password=password)
 
     def logout(self):
