@@ -119,7 +119,7 @@ class DirectoryListing(object):
         self.folder = client.Folder()
 
     def get_root_path(self):
-        return settings.OPENKM['UploadRoot']
+        return settings.OPENKM['configuration']['UploadRoot']
 
     def traverse(self, path=None):
         """
@@ -165,7 +165,7 @@ class DirectoryListing(object):
             pass
         return self.folders
 
-    def get_all_documents_in_folder(self, folder_path=settings.OPENKM['UploadRoot']):
+    def get_all_documents_in_folder(self, folder_path=settings.OPENKM['configuration']['UploadRoot']):
         return self.doc.get_children(folder_path)
 
 
@@ -181,7 +181,7 @@ class DocumentManager(object):
         return self.create_document_on_openkm(document, content)
 
     def create_path_from_filename(self, file_obj):
-        return settings.OPENKM['UploadRoot'] + file_obj.__str__()
+        return settings.OPENKM['configuration']['UploadRoot'] + file_obj.__str__()
 
     def convert_file_content_to_binary_for_transport(self, file_obj):
         return make_file_java_byte_array_compatible(file_obj)
@@ -195,8 +195,10 @@ class DocumentManager(object):
     def get_properties(self, doc_path):
         return self.document.get_properties(doc_path)
 
-class RepositoryManager(object):
-    pass
+class RepositoryManager(client.Repository):
+
+    def __init__(self):
+        super(RepositoryManager, self).__init__(class_name='Repository')
 
 class Property(object):
 
